# zood

zood 网页文档生成的 python 库, 可以将本地 Markdown 文件转为 Web 网页

zood 的页面风格更倾向于纯文档内容而非博客, 您可利用 Github Pages 为每一个仓库部署单独的网页文档

## 主题预览

> 点击图片查看

[![20230728134651](https://raw.githubusercontent.com/learner-lu/picbed/master/20230728134651.png)](https://luzhixing12345.github.io/zood/)

## 安装与使用

```bash
pip install zood
```

参见 [用户使用文档](https://luzhixing12345.github.io/zood/)

## 参考

- [UI](https://remixicon.com/)
- [tholman github-corners](https://tholman.com/github-corners/)
- [lokeshdhakar lightbox2](https://lokeshdhakar.com/projects/lightbox2/)